---
title: <span class="badge object-type-scalar"></span> MilliVolt
---
# <span class="badge object-type-scalar"></span> MilliVolt

Energy: Millivolt (mV)

## Definition

```python
# Energy: Millivolt (mV)
MilliVolt: typing.Literal["mvolt"] = "mvolt"
```
